//------------------------------------------------------ 2021-01-17 --------------
// air-soft gun plate Target Systems
//
// Library
//   TimerOne 
//   TM1637 by Avishay Orpaz V1.2.0
//----------------------------- written by Hiroyuki Iizuka ---- Japan ------------
#include <TimerOne.h>
#include <TM1637Display.h>

boolean       time_update   = false;
unsigned long millisecond10 = 0;
boolean       clock_run     = false;
unsigned char wait;

#define CLK 4
#define DIO 5
TM1637Display display(CLK, DIO);

#define BUZZER 8
#define SENSOR 2        // interrupt 0 = pin2

#define IR      6        // pin 6
#define IR_ON   0

#define LED     13      // pin 13
#define LED_ON  1
#define LED_OFF 0

#define WAIT_MAX   5    // seconds
#define WAIT_MIN   3    // seconds

//----------------------- timer1 interrupts -----------------------
void TimingISR()
{
  if( clock_run ) {
    time_update = true;
    millisecond10++;
  }
}

//----------------------- piezo sensor interrupts -----------------
void impact()
{
  clock_run = false;
  digitalWrite( LED, LED_ON  );
  delay(50);
  digitalWrite( LED, LED_OFF );
}

//----------------------- beep ------------------------------------
void beep()
{
  tone(BUZZER, 5000);   // 5kHz
  delay(500);
  noTone(BUZZER);
}

//----------------------- setup -----------------------------------
void setup()
{
  pinMode( IR,     INPUT  );
  pinMode( SENSOR, INPUT  );
  pinMode( LED,    OUTPUT );
  pinMode( BUZZER, OUTPUT );
  
  display.setBrightness(0x0f);
  Timer1.initialize(10000);           // 10ms period
  Timer1.attachInterrupt(TimingISR); 

  display.showNumberDec(8888, false);
  beep();
  display.clear();

  clock_run = false;
  randomSeed(analogRead(0));

  attachInterrupt(0, impact, RISING );   // 0 = pin2
}

//----------------------- loop ------------------------------------
void loop()
{
  if( time_update ) {
    display.showNumberDec(millisecond10, false); 
    time_update = false;
  }

  if( digitalRead( IR ) == IR_ON ) {
    digitalWrite( LED, LED_ON );
    clock_run = false;
    millisecond10 = 0;
    display.showNumberDec(millisecond10, false);
    wait = random( WAIT_MIN, WAIT_MAX );
    digitalWrite( LED, LED_OFF );
  }
  
  if( wait != 0 ) {
    while( wait > 0 ) {
      delay(1000);
      wait--;
    }
    clock_run = true;    
    beep();
  }
}

//--------------- E N D -------------------------------------------------------------------
